@@ -9,10 +9,10 @@ from __future__ import division
 
 __author__ = "Alan Dozier"
 __copyright__ = "Copyright 2012, The Materials Project"
-__version__ = "1.0"
+__version__ = "1.0.1"
 __maintainer__ = "Alan Dozier"
 __email__ = "adozier@uky.edu"
-__date__ = "Aug 28, 2012"
+__date__ = "Oct. 6, 2012"
 
 import argparse
 import CifFile
@@ -37,6 +37,7 @@ parser.add_argument('calc_type', metavar='calc_type', type=str, nargs=1, help='t
 
 args = parser.parse_args()
 cif_file = args.cif_file[0]
+source =cif_file
 central_atom = args.central_atom[0]
 calc_type = args.calc_type[0]
 
@@ -44,7 +45,7 @@ r = CifParser(cif_file)
 structure = r.get_structures()[0]
 x = FeffInputSet("MaterialsProject")
 
-header = FeffInputSet.get_header(x, structure, cif_file)
+header = FeffInputSet.get_header(x, structure, source)
 print "\n\nHEADER\n"
 print header
 
@@ -62,4 +63,4 @@ print ATOMS
 
 
 
-#FeffInputSet.write_input(x, structure, calc_type, cif_file, "./feffinput", central_atom)
+#FeffInputSet.write_input(x, structure, calc_type, source, "./feffinput", central_atom)
